@@ -2,17 +2,17 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import os
 import typing as t
 
-from typing_extensions import Final, Literal
-
 from ._nothing import Nothing
+from ._type_helpers import Final, Literal
 from ._type_helpers import SupportsLessThan as _SupportsLessThan
 from ._type_helpers import SupportsGreaterOrEqual as _SupportsGreaterOrEqual
 
-if t.TYPE_CHECKING:  # pragma: no cover
+if t.TYPE_CHECKING or os.getenv('CG_GENERATING_DOCS'):  # pragma: no cover
     # pylint: disable=unused-import,invalid-name
-    from ._maybe import Maybe
+    import cg_maybe
 
 _T = t.TypeVar('_T', covariant=True)
 _TT = t.TypeVar('_TT', covariant=True)
@@ -35,11 +35,14 @@ class Just(t.Generic[_T]):
         """Transform this just by applying ``mapper`` to its argument and
         wrapping the result in a new ``Just``.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).map(lambda el: el * el)
         Just(25)
         >>> Nothing.map(lambda el: el * el)
         Nothing
+
+        :param mapper: The function that will be called to map the value if
+            this method is called on a ``Just``.
         """
         return Just(mapper(self.value))
 
@@ -51,18 +54,25 @@ class Just(t.Generic[_T]):
         """Transform this just by applying ``mapper`` to its argument and
         return the result.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).map_or_default(lambda el: el * el, 10)
         25
         >>> Nothing.map_or_default(lambda el: el * el, 10)
         10
+
+        :param mapper: The function that will be called if this method is
+            called on a ``Just``.
+        :param default: The default value that will be called if this method is
+            called on a ``Nothing``.
         """
         return mapper(self.value)
 
-    def chain(self, chainer: t.Callable[[_T], 'Maybe[_TT]']) -> 'Maybe[_TT]':
+    def chain(
+        self, chainer: t.Callable[[_T], 'cg_maybe._maybe.Maybe[_TT]']
+    ) -> 'cg_maybe._maybe.Maybe[_TT]':
         """Transforms ``this`` with a function that returns a ``Maybe``.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).chain(lambda el: Just(el * el))
         Just(25)
         >>> Just(5).chain(lambda _: Nothing)
@@ -71,15 +81,18 @@ class Just(t.Generic[_T]):
         Nothing
         >>> Nothing.chain(lambda _: Nothing)
         Nothing
+
+        :param chainer: The function that will be called if this method is
+            called on ``Just``. It should return a maybe.
         """
         return chainer(self.value)
 
     def chain_nullable(
         self, chainer: t.Callable[[_T], t.Optional['_TT']]
-    ) -> 'Maybe[_TT]':
+    ) -> 'cg_maybe._maybe.Maybe[_TT]':
         """Similar to ``chain`` but for a function that returns an options.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).chain_nullable(lambda el: el * el)
         Just(25)
         >>> Just(5).chain_nullable(lambda _: None)
@@ -90,6 +103,9 @@ class Just(t.Generic[_T]):
         Nothing
         >>> Nothing.chain_nullable(lambda _: None)
         Nothing
+
+        :param chainer: The function that will be called if this method is
+            called on ``Just``. It should return a Optional value.
         """
         # pylint: disable=import-outside-toplevel
         from .utils import from_nullable
@@ -101,69 +117,90 @@ class Just(t.Generic[_T]):
     def __structlog__(self) -> t.Mapping[str, object]:
         return {'type': 'Just', 'value': self.value}
 
-    def alt(self, _alternative: 'Maybe[_T]') -> 'Maybe[_T]':
+    def alt(
+        self,
+        alternative: 'cg_maybe._maybe.Maybe[_T]',  # pylint: disable=unused-argument
+    ) -> 'cg_maybe._maybe.Maybe[_T]':
         """Return the given ``alternative`` if called on a ``Nothing``,
         otherwise the method returns the value it is called on.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).alt(Just(10))
         Just(5)
         >>> Nothing.alt(Just(10))
         Just(10)
+
+        :param alternative: The value return if this method is called on a
+            ``Nothing``.
         """
         return self
 
     def alt_lazy(
-        self, _maker: t.Callable[[], 'Maybe[_Y]']
-    ) -> 'Maybe[t.Union[_Y, _T]]':
+        self,
+        maker: t.Callable[[], 'cg_maybe._maybe.Maybe[_Y]'],  # pylint: disable=unused-argument
+    ) -> 'cg_maybe._maybe.Maybe[t.Union[_Y, _T]]':
         """Return the result of ``maker`` if called on a ``Nothing``, otherwise
         the method returns the value it is called on.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).alt_lazy(lambda: print(10))
         Just(5)
         >>> Nothing.alt_lazy(lambda: [print(10), Just(15)][1])
         10
         Just(15)
+
+        :param maker: The function that will be called if this method is called
+            on a ``Nothing``.
         """
         return self
 
     def unsafe_extract(self) -> _T:
         """Get the value from a ``Just``, or raise if called on a ``Nothing``.
 
+        >>> from cg_maybe import Nothing, Just
+        >>> Nothing.unsafe_extract()
+        Traceback (most recent call last):
+        ...
+        AssertionError
         >>> Just(10).unsafe_extract()
         10
         """
         return self.value
 
-    def or_default_lazy(self, _producer: t.Callable[[], _Y]) -> _T:
+    def or_default_lazy(self, producer: t.Callable[[], _Y]) -> _T:  # pylint: disable=unused-argument
         """Get the value from a ``Just``, or return the given a default as
         produced by the given function.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).or_default_lazy(lambda: [print('call'), 10][-1])
         5
         >>> Nothing.or_default_lazy(lambda: [print('call'), 10][-1])
         call
         10
+
+        :param producer: The function that will produce the default value for
+            ``Nothing``.
         """
         return self.value
 
-    def or_default(self, _value: _Y) -> _T:
-        """Get the value from a ``Just``, or return the given ``default``.
+    def or_default(self, value: _Y) -> _T:  # pylint: disable=unused-argument
+        """Get the value from a ``Just``, or return the given default value.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).or_default(10)
         5
         >>> Nothing.or_default(10)
         10
+
+        :param value: The default value that will be returned for a
+            ``Nothing``.
         """
         return self.value
 
     def or_none(self) -> _T:
         """Get the value from a ``Just``, or ``None``.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).or_none()
         5
         >>> Nothing.or_none() is None
@@ -179,7 +216,7 @@ class Just(t.Generic[_T]):
     ) -> _TT:
         """A poor mans version of pattern matching.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> obj1, obj2 = object(), object()
         >>> on_just = lambda el: [print('just', el), obj1][1]
         >>> on_nothing = lambda: [print('nothing'), obj2][1]
@@ -189,6 +226,11 @@ class Just(t.Generic[_T]):
         >>> Just(5).case_of(just=on_just, nothing=on_nothing) is obj1
         just 5
         True
+
+        :param just: The function that will be called if this method is called
+            on a ``Just``.
+        :param nothing: The function that will be called if this method is
+            called on a ``Nothing``.
         """
         return just(self.value)
 
@@ -196,13 +238,16 @@ class Just(t.Generic[_T]):
         """Call the given callback with the wrapped value if this value is a
         ``Just``, otherwise do nothing.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> printer = lambda el: print('call', el)
         >>> Nothing.if_just(printer)
         Nothing
         >>> Just(5).if_just(printer)
         call 5
         Just(5)
+
+        :param callback: The function that will be called if this method is
+            called on a ``Just``. It will be provided the value of the just.
         """
         callback(self.value)
         return self
@@ -211,21 +256,25 @@ class Just(t.Generic[_T]):
         """Call the given callback if this value is a ``Nothing``, otherwise do
         nothing.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> printer = lambda: print('call')
         >>> _ = Just(5).if_nothing(printer)
         >>> _ = Nothing.if_nothing(printer)
         call
+
+        :param callback: The function that will be called if this method is
+            called on a ``Nothing``.
         """
         return self
 
     def try_extract(
-        self, _make_exception: t.Union[t.Callable[[], Exception], Exception]
+        self,
+        make_exception: t.Union[t.Callable[[], Exception], Exception],  # pylint: disable=unused-argument
     ) -> _T:
         """Try to extract the value, raising an exception created by the given
         argument if the value is ``Nothing``.
 
-        >>> from ._nothing import Nothing
+        >>> from cg_maybe import Just, Nothing
         >>> Just(5).try_extract(Exception)
         5
         >>> Nothing.try_extract(lambda: Exception())
@@ -236,6 +285,11 @@ class Just(t.Generic[_T]):
         Traceback (most recent call last):
         ...
         Exception
+
+        :param make_exception: The function that will be called to create an
+            exception that will be raised if called on a ``Nothing``. If this
+            value is an instance of ``BaseException`` it will be raised
+            directly.
         """
         return self.value
 
@@ -248,17 +302,23 @@ class Just(t.Generic[_T]):
 
         This means that ``value.attr('attr')`` is equal to
         ``value.map(lambda v: v.attr)``.
+
+        :param attr: The attribute to get of the value of a ``Just``.
         """
         return Just(getattr(self.value, attr))
 
-    def join(self: 'Just[Maybe[_Y]]') -> 'Maybe[_Y]':
+    def join(
+        self: 'Just[cg_maybe._maybe.Maybe[_Y]]'
+    ) -> 'cg_maybe._maybe.Maybe[_Y]':
         """Join a ``Just`` of a ``Maybe``.
 
         This is equal to ``maybe.chain(x => x)``.
         """
         return self.value
 
-    def filter(self, pred: t.Callable[[_T], bool]) -> 'Maybe[_T]':
+    def filter(
+        self, pred: t.Callable[[_T], bool]
+    ) -> 'cg_maybe._maybe.Maybe[_T]':
         """Filter this maybe with a predicate.
 
         :param pred: The predicate to filter the maybe with.
@@ -271,6 +331,11 @@ class Just(t.Generic[_T]):
 
     def eq(self: 'Just[_Y]', val: _Y) -> bool:
         """Check if a value of a ``Just`` is equal to the given value.
+
+        :param val: The value to check this ``Maybe`` against.
+
+        :returns: ``True`` if ``val`` equals the value of the ``Just``, always
+            ``False`` for a ``Nothing``.
         """
         return self.value == val
 
@@ -279,6 +344,11 @@ class Just(t.Generic[_T]):
         val: _Y,
     ) -> bool:
         """Check if a value of a ``Just`` is not equal to the given value.
+
+        :param val: The value to check this ``Maybe`` against.
+
+        :returns: ``True`` if ``val`` does not equal the value of the ``Just``,
+            always ``False`` for a ``Nothing``.
         """
         return self.value != val
 
@@ -287,6 +357,11 @@ class Just(t.Generic[_T]):
         val: _SupportsLessThan[_T],
     ) -> bool:
         """Check if a value of a ``Just`` is less than the given value.
+
+        :param val: The value to check this ``Maybe`` against.
+
+        :returns: ``True`` if ``val`` is less than the value of the ``Just``,
+            always ``False`` for a ``Nothing``.
         """
         return self.value < val
 
@@ -295,6 +370,11 @@ class Just(t.Generic[_T]):
         val: _SupportsGreaterOrEqual[_T],
     ) -> bool:
         """Check if a value of a ``Just`` is <= to the given value.
+
+        :param val: The value to check this ``Maybe`` against.
+
+        :returns: ``True`` if ``val`` is less than or equal to the value of the
+            ``Just``, always ``False`` for a ``Nothing``.
         """
         return self.value <= val
 
@@ -303,6 +383,11 @@ class Just(t.Generic[_T]):
         val: _SupportsLessThan[_T],
     ) -> bool:
         """Check if a value of a ``Just`` is > to the given value.
+
+        :param val: The value to check this ``Maybe`` against.
+
+        :returns: ``True`` if ``val`` is greater than to the value of the
+            ``Just``, always ``False`` for a ``Nothing``.
         """
         return self.value > val
 
@@ -311,5 +396,10 @@ class Just(t.Generic[_T]):
         val: _SupportsGreaterOrEqual[_T],
     ) -> bool:
         """Check if a value of a ``Just`` is >= to the given value.
+
+        :param val: The value to check this ``Maybe`` against.
+
+        :returns: ``True`` if ``val`` is greater than or equal to the value of the
+            ``Just``, always ``False`` for a ``Nothing``.
         """
         return self.value >= val
