@@ -590,7 +590,9 @@ class DiscriminatedUnion(t.Generic[_T], Parser[_T]):
         def _is_possible(arg: _Argument) -> t.Sequence[str]:
             if (
                 isinstance(arg, RequiredArgument) and
-                isinstance(arg.value, StringEnum) and len(arg.value.opts) == 1
+                isinstance(arg.value, StringEnum) and
+                arg.value.str_parser is SimpleValue.str and
+                len(arg.value.opts) == 1
             ):
                 return (next(iter(arg.value.opts)), )
             return ()
