@@ -6,6 +6,7 @@ import functools
 import dataclasses
 
 from ._utils import USE_SLOTS as _USE_SLOTS
+from ._utils import Literal
 from ._mapping import BaseFixedMapping
 
 __all__ = ('swaggerize', )
@@ -30,7 +31,8 @@ class _SwaggerFunc:
 
 _SWAGGER_FUNCS: t.Dict[str, t.Dict[t.Optional[str], _SwaggerFunc]] = {}
 
-_NameT = t.Union[str, t.Mapping[str, str]]
+_NameT = t.Union[str, t.Mapping[Literal['GET', 'POST', 'PATCH', 'DELETE',
+                                        'PUT'], str]]
 
 
 def swaggerize(
