@@ -17,6 +17,13 @@ except ImportError:  # pragma: no cover
         return ', '.join(lst)
 
 
+if sys.version_info >= (3, 8):
+    # pylint: disable=unused-import
+    from typing import Final, Literal, Protocol, TypedDict
+else:  # pragma: no cover
+    from typing_extensions import Final, Literal, Protocol, TypedDict
+
+
 def _issubclass(value: t.Any, cls: t.Type) -> bool:
     return isinstance(value, type) and issubclass(value, cls)
 
