@@ -3,12 +3,10 @@
 import copy
 import typing as t
 
-from typing_extensions import Protocol
-
 import cg_maybe
 
 from ._utils import USE_SLOTS as _USE_SLOTS
-from ._utils import readable_join
+from ._utils import Protocol, readable_join
 
 __all__ = ('ParseError', 'SimpleParseError', 'MultipleParseErrors')
 
