@@ -24,6 +24,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from ..models.course_role_as_json_with_perms import (
         CourseRoleAsJSONWithPerms,
     )
+    from ..models.course_section import CourseSection
     from ..models.course_snippet import CourseSnippet
     from ..models.course_statistics_as_json import CourseStatisticsAsJSON
     from ..models.create_assignment_course_data import (
@@ -32,6 +33,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from ..models.create_course_data import CreateCourseData
     from ..models.create_group_set_course_data import CreateGroupSetCourseData
     from ..models.create_role_course_data import CreateRoleCourseData
+    from ..models.create_section_course_data import CreateSectionCourseData
     from ..models.create_snippet_course_data import CreateSnippetCourseData
     from ..models.email_users_course_data import EmailUsersCourseData
     from ..models.extended_course import ExtendedCourse
@@ -639,6 +641,103 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_sections(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[CourseSection]":
+        """Get all sections of this course.
+
+        :param course_id: The id of the course to get the sections for.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A list of all sections connected to this course.
+        """
+
+        url = "/api/v1/courses/{courseId}/sections/".format(courseId=course_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.course_section import CourseSection
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(parsers.ParserFor.make(CourseSection))
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def create_section(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "CreateSectionCourseData"],
+        *,
+        course_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "CourseSection":
+        """Create a new course section.
+
+        :param json_body: The body of the request. See
+            :class:`.CreateSectionCourseData` for information about the
+            possible fields. You can provide this data as a
+            :class:`.CreateSectionCourseData` or as a dictionary.
+        :param course_id: The id of the course to create a section for.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The new section.
+        """
+
+        url = "/api/v1/courses/{courseId}/sections/".format(courseId=course_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.post(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.course_section import CourseSection
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(CourseSection)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def put_price(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PutPriceCourseData"],
