@@ -14,6 +14,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     import codegrade
 
     from ..models.extended_group import ExtendedGroup
+    from ..models.rename_group_group_data import RenameGroupGroupData
     from ..models.user_input import UserInput
 
 
@@ -219,3 +220,55 @@ class GroupService(t.Generic[_ClientT]):
                 ),
             ),
         )
+
+    def rename_group(
+        self: "GroupService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "RenameGroupGroupData"],
+        *,
+        group_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "ExtendedGroup":
+        """Update the name of the group.
+
+        :param json_body: The body of the request. See
+            :class:`.RenameGroupGroupData` for information about the possible
+            fields. You can provide this data as a
+            :class:`.RenameGroupGroupData` or as a dictionary.
+        :param group_id: The id of the group that should be updated.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The group with the updated name.
+        """
+
+        url = "/api/v1/groups/{groupId}/name".format(groupId=group_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.post(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.extended_group import ExtendedGroup
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(ExtendedGroup)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
