@@ -17,11 +17,17 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from ..models.extended_course import ExtendedCourse
     from ..models.extended_tenant import ExtendedTenant
     from ..models.lti_provider_base import LTIProviderBase
+    from ..models.no_permissions import NoPermissions
     from ..models.partial_all_site_settings import PartialAllSiteSettings
+    from ..models.patch_role_tenant_data import PatchRoleTenantData
     from ..models.patch_settings_tenant_data import PatchSettingsTenantData
     from ..models.patch_tenant_data import PatchTenantData
     from ..models.put_price_tenant_data import PutPriceTenantData
+    from ..models.tenant_permissions import TenantPermissions
     from ..models.tenant_price import TenantPrice
+    from ..models.tenant_role_as_json_with_perms import (
+        TenantRoleAsJSONWithPerms,
+    )
     from ..models.tenant_statistics import TenantStatistics
 
 
@@ -480,6 +486,107 @@ class TenantService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_permissions(
+        self: "TenantService[codegrade.client.AuthenticatedClient]",
+        *,
+        tenant_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Union[TenantPermissions, NoPermissions]":
+        """Get the permissions of the logged in user for this tenant.
+
+        If the user does not have an associated role within the tenant, the
+        global permissions of the user are returned.
+
+        :param tenant_id: The tenant for which to get the permissions.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The courses for this tenant.
+        """
+
+        url = "/api/v1/tenants/{tenantId}/permissions/".format(
+            tenantId=tenant_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.no_permissions import NoPermissions
+            from ..models.tenant_permissions import TenantPermissions
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.make_union(
+                    parsers.ParserFor.make(TenantPermissions),
+                    parsers.ParserFor.make(NoPermissions),
+                )
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def get_roles(
+        self: "TenantService[codegrade.client.AuthenticatedClient]",
+        *,
+        tenant_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[TenantRoleAsJSONWithPerms]":
+        """Get all roles of this tenant with their permissions
+
+        :param tenant_id: The tenant to get the roles for.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An array of roles.
+        """
+
+        url = "/api/v1/tenants/{tenantId}/roles/".format(tenantId=tenant_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.tenant_role_as_json_with_perms import (
+                TenantRoleAsJSONWithPerms,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(parsers.ParserFor.make(TenantRoleAsJSONWithPerms))
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_settings(
         self,
         *,
@@ -635,3 +742,55 @@ class TenantService(t.Generic[_ClientT]):
                 ),
             ),
         )
+
+    def patch_role(
+        self: "TenantService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "PatchRoleTenantData"],
+        *,
+        tenant_id: "str",
+        role_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Update the `Permission` of a given `TenantRole`.
+
+        :param json_body: The body of the request. See
+            :class:`.PatchRoleTenantData` for information about the possible
+            fields. You can provide this data as a
+            :class:`.PatchRoleTenantData` or as a dictionary.
+        :param tenant_id: The tenant to patch the role for.
+        :param role_id: The id of the tenant role.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An empty response with return code 204.
+        """
+
+        url = "/api/v1/tenants/{tenantId}/roles/{roleId}".format(
+            tenantId=tenant_id, roleId=role_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.patch(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
