@@ -10,6 +10,7 @@ from ._submission_rubric_item_data_parser import (
 )
 from .about import About
 from .abstract_role import AbstractRole
+from .add_users_section_data import AddUsersSectionData
 from .all_auto_test_results import AllAutoTestResults
 from .all_site_settings import AllSiteSettings
 from .any_auto_test_step_as_json import AnyAutoTestStepAsJSON
@@ -34,10 +35,17 @@ from .assignment_grading_settings_as_json import (
 )
 from .assignment_kind import AssignmentKind
 from .assignment_login_link import AssignmentLoginLink
+from .assignment_max_points_enabled_setting import (
+    AssignmentMaxPointsEnabledSetting,
+)
 from .assignment_peer_feedback_connection import (
     AssignmentPeerFeedbackConnection,
 )
 from .assignment_peer_feedback_settings import AssignmentPeerFeedbackSettings
+from .assignment_percentage_decimals_setting import (
+    AssignmentPercentageDecimalsSetting,
+)
+from .assignment_point_decimals_setting import AssignmentPointDecimalsSetting
 from .assignment_state_enum import AssignmentStateEnum
 from .assignment_template import AssignmentTemplate
 from .at_image_caching_enabled_setting import AtImageCachingEnabledSetting
@@ -106,6 +114,9 @@ from .auto_test_step_validation_exception import (
 )
 from .auto_test_suite import AutoTestSuite
 from .auto_test_unit_test_message_setting import AutoTestUnitTestMessageSetting
+from .automatic_lti1p3_assignment_import_setting import (
+    AutomaticLti1p3AssignmentImportSetting,
+)
 from .automatic_lti_role_enabled_setting import AutomaticLtiRoleEnabledSetting
 from .base_about import BaseAbout
 from .base_auto_test_quality_comment import BaseAutoTestQualityComment
@@ -169,6 +180,7 @@ from .course_register_response import CourseRegisterResponse
 from .course_registration_link import CourseRegistrationLink
 from .course_role import CourseRole
 from .course_role_as_json_with_perms import CourseRoleAsJSONWithPerms
+from .course_section import CourseSection
 from .course_snippet import CourseSnippet
 from .course_state import CourseState
 from .course_statistics_as_json import CourseStatisticsAsJSON
@@ -188,6 +200,7 @@ from .create_repository_git_provider_data import (
     CreateRepositoryGitProviderData,
 )
 from .create_role_course_data import CreateRoleCourseData
+from .create_section_course_data import CreateSectionCourseData
 from .create_snippet_course_data import CreateSnippetCourseData
 from .create_snippet_data import CreateSnippetData
 from .create_sso_provider_data import CreateSSOProviderData
@@ -215,6 +228,7 @@ from .extended_auto_test_result import ExtendedAutoTestResult
 from .extended_auto_test_run import ExtendedAutoTestRun
 from .extended_course import ExtendedCourse
 from .extended_course_registration_link import ExtendedCourseRegistrationLink
+from .extended_course_section import ExtendedCourseSection
 from .extended_group import ExtendedGroup
 from .extended_job import ExtendedJob
 from .extended_non_deleted_comment_reply import ExtendedNonDeletedCommentReply
@@ -238,6 +252,8 @@ from .file_tree import FileTree
 from .file_type import FileType
 from .finalized_lti1p1_provider import FinalizedLTI1p1Provider
 from .finalized_lti1p3_provider import FinalizedLTI1p3Provider
+from .find_element_interval_setting import FindElementIntervalSetting
+from .find_element_max_tries_setting import FindElementMaxTriesSetting
 from .first_phase_lti_launch_exception import FirstPhaseLTILaunchException
 from .fixture_like import FixtureLike
 from .frontend_site_settings import FrontendSiteSettings
@@ -289,6 +305,9 @@ from .io_test_log import IOTestLog
 from .io_test_option import IOTestOption
 from .io_test_step_log import IOTestStepLog
 from .io_test_step_log_base import IOTestStepLogBase
+from .is_admin_permission_enabled_setting import (
+    IsAdminPermissionEnabledSetting,
+)
 from .job import Job
 from .json_create_auto_test import JsonCreateAutoTest
 from .json_create_tenant import JsonCreateTenant
@@ -317,6 +336,9 @@ from .lti1p3_provider_presentation_as_json import (
     LTI1p3ProviderPresentationAsJSON,
 )
 from .lti_enabled_setting import LtiEnabledSetting
+from .lti_lock_date_copying_enabled_setting import (
+    LtiLockDateCopyingEnabledSetting,
+)
 from .lti_provider_base import LTIProviderBase
 from .max_document_update_size_setting import MaxDocumentUpdateSizeSetting
 from .max_dynamo_file_size_setting import MaxDynamoFileSizeSetting
@@ -395,6 +417,7 @@ from .patch_rubric_category_type_assignment_data import (
 from .patch_rubric_result_submission_data import (
     PatchRubricResultSubmissionData,
 )
+from .patch_section_data import PatchSectionData
 from .patch_settings_tenant_data import PatchSettingsTenantData
 from .patch_site_settings_data import PatchSiteSettingsData
 from .patch_snippet_course_data import PatchSnippetCourseData
@@ -488,6 +511,8 @@ from .tenant_permissions import TenantPermissions
 from .tenant_price import TenantPrice
 from .tenant_role_as_json_with_perms import TenantRoleAsJSONWithPerms
 from .tenant_statistics import TenantStatistics
+from .tour_configurations_setting import TourConfigurationsSetting
+from .tour_polling_interval_setting import TourPollingIntervalSetting
 from .transaction import Transaction
 from .transaction_state import TransactionState
 from .types import *
