@@ -438,6 +438,18 @@ class AllSiteSettings(FrontendSiteSettings):
             "FIND_ELEMENT_INTERVAL": to_dict(self.find_element_interval),
             "FIND_ELEMENT_MAX_TRIES": to_dict(self.find_element_max_tries),
             "TOUR_CONFIGURATIONS": to_dict(self.tour_configurations),
+            "ASSIGNMENT_PERCENTAGE_DECIMALS": to_dict(
+                self.assignment_percentage_decimals
+            ),
+            "ASSIGNMENT_POINT_DECIMALS": to_dict(
+                self.assignment_point_decimals
+            ),
+            "LTI_LOCK_DATE_COPYING_ENABLED": to_dict(
+                self.lti_lock_date_copying_enabled
+            ),
+            "ASSIGNMENT_MAX_POINTS_ENABLED": to_dict(
+                self.assignment_max_points_enabled
+            ),
         }
         return res
 
@@ -520,6 +532,10 @@ class AllSiteSettings(FrontendSiteSettings):
             find_element_interval=parsed.FIND_ELEMENT_INTERVAL,
             find_element_max_tries=parsed.FIND_ELEMENT_MAX_TRIES,
             tour_configurations=parsed.TOUR_CONFIGURATIONS,
+            assignment_percentage_decimals=parsed.ASSIGNMENT_PERCENTAGE_DECIMALS,
+            assignment_point_decimals=parsed.ASSIGNMENT_POINT_DECIMALS,
+            lti_lock_date_copying_enabled=parsed.LTI_LOCK_DATE_COPYING_ENABLED,
+            assignment_max_points_enabled=parsed.ASSIGNMENT_MAX_POINTS_ENABLED,
         )
         res.raw_data = d
         return res
