@@ -67,7 +67,7 @@ class Assignment:
     #: the idea that a 10 is a 'perfect' score. So if this value is 12 a user
     #: can score 2 additional bonus points. If this value is `None` it is unset
     #: and regarded as a 10.
-    max_grade: "t.Optional[float]"
+    max_grade: "float"
     #: Settings that influence how the grade for a submission can be
     #: determined. TODO: Should we also move max\_grade and/or
     #: fixed\_max\_rubric\_points to the grading object?
@@ -82,8 +82,10 @@ class Assignment:
     auto_test_id: "t.Optional[int]"
     #: Can you upload files to this assignment.
     files_upload_enabled: "bool"
-    #: Can you connect git to this assignment
+    #: Can you connect git to this assignment.
     webhook_upload_enabled: "bool"
+    #: Can you use the editor for this assignment.
+    editor_upload_enabled: "bool"
     #: The maximum amount of submission a student may create, inclusive. The
     #: value `null` indicates that there is no limit.
     max_submissions: "t.Optional[int]"
@@ -225,7 +227,7 @@ class Assignment:
             ),
             rqa.RequiredArgument(
                 "max_grade",
-                rqa.Nullable(rqa.SimpleValue.float),
+                rqa.SimpleValue.float,
                 doc=(
                     "The maximum grade you can get for this assignment. This"
                     " is based around the idea that a 10 is a 'perfect' score."
@@ -270,7 +272,12 @@ class Assignment:
             rqa.RequiredArgument(
                 "webhook_upload_enabled",
                 rqa.SimpleValue.bool,
-                doc="Can you connect git to this assignment",
+                doc="Can you connect git to this assignment.",
+            ),
+            rqa.RequiredArgument(
+                "editor_upload_enabled",
+                rqa.SimpleValue.bool,
+                doc="Can you use the editor for this assignment.",
             ),
             rqa.RequiredArgument(
                 "max_submissions",
@@ -404,6 +411,7 @@ class Assignment:
             "auto_test_id": to_dict(self.auto_test_id),
             "files_upload_enabled": to_dict(self.files_upload_enabled),
             "webhook_upload_enabled": to_dict(self.webhook_upload_enabled),
+            "editor_upload_enabled": to_dict(self.editor_upload_enabled),
             "max_submissions": to_dict(self.max_submissions),
             "cool_off_period": to_dict(self.cool_off_period),
             "amount_in_cool_off_period": to_dict(
@@ -449,6 +457,7 @@ class Assignment:
             auto_test_id=parsed.auto_test_id,
             files_upload_enabled=parsed.files_upload_enabled,
             webhook_upload_enabled=parsed.webhook_upload_enabled,
+            editor_upload_enabled=parsed.editor_upload_enabled,
             max_submissions=parsed.max_submissions,
             cool_off_period=parsed.cool_off_period,
             amount_in_cool_off_period=parsed.amount_in_cool_off_period,
