@@ -15,11 +15,11 @@ from ..utils import to_dict
 class CoursePermMap:
     """The mapping between permission and value for a user."""
 
-    #: Users with this permission can submit work to an assignment for other
-    #: users. This means they can submit work that will have another user as
-    #: the author.
+    #: Users with this permission can create submissions in assignments for
+    #: other users. This means they can create submissions that will have
+    #: another user as the author.
     can_submit_others_work: "bool"
-    #: Users with this permission can submit their work to assignments of this
+    #: Users with this permission can create submissions in assignments of this
     #: course. Usually only students have this permission.
     can_submit_own_work: "bool"
     #: Users with this permission can edit files in the submissions of this
@@ -60,7 +60,7 @@ class CoursePermMap:
     can_edit_course_users: "bool"
     #: Users with this permission can create new assignments for this course.
     can_create_assignment: "bool"
-    #: Users with this permission can submit their work after the deadline of
+    #: Users with this permission can create submissions after the deadline of
     #: an assignment.
     can_upload_after_deadline: "bool"
     #: Users with this permission can see which grader is assigned to assess a
@@ -69,8 +69,7 @@ class CoursePermMap:
     #: Users with this permission can update the rubrics for the assignments of
     #: this course.
     manage_rubrics: "bool"
-    #: Users with this permission can view the teacher's revision of their
-    #: submitted work.
+    #: Users with this permission can view the teacher's revision.
     can_view_own_teacher_files: "bool"
     #: Users with this permission can see the grade history of an assignment.
     can_see_grade_history: "bool"
@@ -90,7 +89,8 @@ class CoursePermMap:
     #: Users with this permission can view the summary of a plagiarism check
     #: and see details of a plagiarism case. To view a plagiarism case between
     #: this and another course, the user must also have either this permission,
-    #: or both "View assignments" and "View other's work" in the other course.
+    #: or both "View assignments" and "View submissions by others" in the other
+    #: course.
     can_view_plagiarism: "bool"
     #: Users with this permission can add and delete plagiarism runs.
     can_manage_plagiarism: "bool"
@@ -165,14 +165,14 @@ class CoursePermMap:
     #: Users with this permission can view the analytics dashboard of an
     #: assignment.
     can_view_analytics: "bool"
-    #: Users with this permission can edit inline and general comments left by
-    #: other users
+    #: Users with this permission can edit inline and general comments authored
+    #: by other users
     can_edit_others_comments: "bool"
     #: Users with this permission can add and reply to inline and general
     #: comments on submissions they are the author of
     can_add_own_inline_comments: "bool"
     #: Users with this permission may see the edit history of inline and
-    #: general comments placed by others
+    #: general comments authored by others
     can_view_others_comment_edits: "bool"
     #: Users with this permission can view the author of inline and general
     #: feedback.
@@ -193,7 +193,7 @@ class CoursePermMap:
     can_edit_peer_feedback_settings: "bool"
     #: Users with this permission will receive login links if this is enabled
     #: for the assignment. You should not give this permission to users with
-    #: powerful permissions (such as "Can grade work").
+    #: powerful permissions (such as "Grade submissions").
     can_receive_login_links: "bool"
     #: Users with this permission can see a course that is archived. Users that
     #: do not have this permission will not be able to see any data (e.g.
@@ -206,7 +206,7 @@ class CoursePermMap:
     #: Users with this permission can edit general information of a course, for
     #: example the name.
     can_edit_course_info: "bool"
-    #: Users with this permission can still submit their work after the lock
+    #: Users with this permission can still create submissions after the lock
     #: date of an assignment.
     can_upload_after_lock_date: "bool"
     #: Users with this permission are allowed to see inline and general peer
@@ -218,10 +218,41 @@ class CoursePermMap:
     #: Users with this permission can view AutoTest results of other users they
     #: are peer reviewing.
     can_view_peer_review_autotest_results: "bool"
-    #: Users with this permission can submit their work for group assignments
+    #: Users with this permission can create submissions for group assignments
     #: without being member of a group or when their group does not meet the
     #: minimum size requirements.
     can_upload_without_group: "bool"
+    #: Users with this permission are allowed to create submissions for users
+    #: that are in the same section as they are.
+    can_submit_others_in_section_work: "bool"
+    #: Users with this permission are allowed to edit submissions by users that
+    #: are in the same section as they are.
+    can_edit_others_in_section_work: "bool"
+    #: Users with this permission are allowed to see submissions by users that
+    #: are in the same section as they are.
+    can_see_others_in_section_work: "bool"
+    #: Users with this permission are allowed to edit groups that they are not
+    #: in, but only groups where at least one user is in the same section as
+    #: they are.
+    can_edit_others_in_section_groups: "bool"
+    #: Users with this permisison can view groups they are not in, and the
+    #: members of those groups, but only if at least one person in the group is
+    #: in the same section as they are.
+    can_view_others_in_section_groups: "bool"
+    #: Users with this permission can edit inline and general comments authored
+    #: by others that are in the same section as they are.
+    can_edit_others_in_section_comments: "bool"
+    #: Users with this permission can view the edit history of inline and
+    #: general comments authored by others that are in the same section as they
+    #: are.
+    can_view_others_in_section_comment_edits: "bool"
+    #: Users with this permission can view all the course's sections, but not
+    #: the members of the section for which you need the "List course users"
+    #: permission.
+    can_view_course_sections: "bool"
+    #: Users with this permissions can edit course sections, add users to them,
+    #: and remove users from them.
+    can_edit_course_sections: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -231,16 +262,16 @@ class CoursePermMap:
                 "can_submit_others_work",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can submit work to an"
-                    " assignment for other users. This means they can submit"
-                    " work that will have another user as the author."
+                    "Users with this permission can create submissions in"
+                    " assignments for other users. This means they can create"
+                    " submissions that will have another user as the author."
                 ),
             ),
             rqa.RequiredArgument(
                 "can_submit_own_work",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can submit their work to"
+                    "Users with this permission can create submissions in"
                     " assignments of this course. Usually only students have"
                     " this permission."
                 ),
@@ -353,7 +384,7 @@ class CoursePermMap:
                 "can_upload_after_deadline",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can submit their work after"
+                    "Users with this permission can create submissions after"
                     " the deadline of an assignment."
                 ),
             ),
@@ -378,7 +409,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view the teacher's"
-                    " revision of their submitted work."
+                    " revision."
                 ),
             ),
             rqa.RequiredArgument(
@@ -429,8 +460,8 @@ class CoursePermMap:
                     " plagiarism check and see details of a plagiarism case."
                     " To view a plagiarism case between this and another"
                     " course, the user must also have either this permission,"
-                    ' or both "View assignments" and "View other\'s work" in'
-                    " the other course."
+                    ' or both "View assignments" and "View submissions by'
+                    ' others" in the other course.'
                 ),
             ),
             rqa.RequiredArgument(
@@ -644,7 +675,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can edit inline and general"
-                    " comments left by other users"
+                    " comments authored by other users"
                 ),
             ),
             rqa.RequiredArgument(
@@ -661,7 +692,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission may see the edit history of"
-                    " inline and general comments placed by others"
+                    " inline and general comments authored by others"
                 ),
             ),
             rqa.RequiredArgument(
@@ -715,7 +746,7 @@ class CoursePermMap:
                     "Users with this permission will receive login links if"
                     " this is enabled for the assignment. You should not give"
                     " this permission to users with powerful permissions (such"
-                    ' as "Can grade work").'
+                    ' as "Grade submissions").'
                 ),
             ),
             rqa.RequiredArgument(
@@ -750,7 +781,7 @@ class CoursePermMap:
                 "can_upload_after_lock_date",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can still submit their work"
+                    "Users with this permission can still create submissions"
                     " after the lock date of an assignment."
                 ),
             ),
@@ -783,12 +814,92 @@ class CoursePermMap:
                 "can_upload_without_group",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can submit their work for"
+                    "Users with this permission can create submissions for"
                     " group assignments without being member of a group or"
                     " when their group does not meet the minimum size"
                     " requirements."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_submit_others_in_section_work",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission are allowed to create"
+                    " submissions for users that are in the same section as"
+                    " they are."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_edit_others_in_section_work",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission are allowed to edit"
+                    " submissions by users that are in the same section as"
+                    " they are."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_see_others_in_section_work",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission are allowed to see submissions"
+                    " by users that are in the same section as they are."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_edit_others_in_section_groups",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission are allowed to edit groups"
+                    " that they are not in, but only groups where at least one"
+                    " user is in the same section as they are."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_others_in_section_groups",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permisison can view groups they are not"
+                    " in, and the members of those groups, but only if at"
+                    " least one person in the group is in the same section as"
+                    " they are."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_edit_others_in_section_comments",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can edit inline and general"
+                    " comments authored by others that are in the same section"
+                    " as they are."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_others_in_section_comment_edits",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can view the edit history of"
+                    " inline and general comments authored by others that are"
+                    " in the same section as they are."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_course_sections",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can view all the course's"
+                    " sections, but not the members of the section for which"
+                    ' you need the "List course users" permission.'
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_edit_course_sections",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permissions can edit course sections, add"
+                    " users to them, and remove users from them."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -909,6 +1020,29 @@ class CoursePermMap:
                 self.can_view_peer_review_autotest_results
             ),
             "can_upload_without_group": to_dict(self.can_upload_without_group),
+            "can_submit_others_in_section_work": to_dict(
+                self.can_submit_others_in_section_work
+            ),
+            "can_edit_others_in_section_work": to_dict(
+                self.can_edit_others_in_section_work
+            ),
+            "can_see_others_in_section_work": to_dict(
+                self.can_see_others_in_section_work
+            ),
+            "can_edit_others_in_section_groups": to_dict(
+                self.can_edit_others_in_section_groups
+            ),
+            "can_view_others_in_section_groups": to_dict(
+                self.can_view_others_in_section_groups
+            ),
+            "can_edit_others_in_section_comments": to_dict(
+                self.can_edit_others_in_section_comments
+            ),
+            "can_view_others_in_section_comment_edits": to_dict(
+                self.can_view_others_in_section_comment_edits
+            ),
+            "can_view_course_sections": to_dict(self.can_view_course_sections),
+            "can_edit_course_sections": to_dict(self.can_edit_course_sections),
         }
         return res
 
@@ -986,6 +1120,15 @@ class CoursePermMap:
             can_see_anonymized_names=parsed.can_see_anonymized_names,
             can_view_peer_review_autotest_results=parsed.can_view_peer_review_autotest_results,
             can_upload_without_group=parsed.can_upload_without_group,
+            can_submit_others_in_section_work=parsed.can_submit_others_in_section_work,
+            can_edit_others_in_section_work=parsed.can_edit_others_in_section_work,
+            can_see_others_in_section_work=parsed.can_see_others_in_section_work,
+            can_edit_others_in_section_groups=parsed.can_edit_others_in_section_groups,
+            can_view_others_in_section_groups=parsed.can_view_others_in_section_groups,
+            can_edit_others_in_section_comments=parsed.can_edit_others_in_section_comments,
+            can_view_others_in_section_comment_edits=parsed.can_view_others_in_section_comment_edits,
+            can_view_course_sections=parsed.can_view_course_sections,
+            can_edit_course_sections=parsed.can_edit_course_sections,
         )
         res.raw_data = d
         return res
