@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import typing as t
 from dataclasses import dataclass, field
 
@@ -14,8 +15,7 @@ from .auto_test_quality_comment import AutoTestQualityComment
 from .auto_test_result import AutoTestResult
 from .auto_test_runner import AutoTestRunner
 from .auto_test_step_result import AutoTestStepResult
-from .base_file import BaseFile
-from .directory_with_children import DirectoryWithChildren
+from .file_tree import FileTree, FileTreeParser
 
 
 @dataclass
@@ -52,7 +52,7 @@ class ExtendedAutoTestResult(AutoTestResult):
     final_result: "bool"
     #: A mapping between suite id and the files written to the AutoTest output
     #: folder in that suite.
-    suite_files: "t.Mapping[str, t.Sequence[t.Union[BaseFile, DirectoryWithChildren]]]"
+    suite_files: "t.Mapping[str, t.Sequence[FileTree]]"
     #: The quality comments produced by this AutoTest result.
     quality_comments: "t.Sequence[AutoTestQualityComment]"
     #: The runners that could be used to run this result. You can use this to
@@ -137,14 +137,7 @@ class ExtendedAutoTestResult(AutoTestResult):
                 ),
                 rqa.RequiredArgument(
                     "suite_files",
-                    rqa.LookupMapping(
-                        rqa.List(
-                            parsers.make_union(
-                                parsers.ParserFor.make(BaseFile),
-                                parsers.ParserFor.make(DirectoryWithChildren),
-                            )
-                        )
-                    ),
+                    rqa.LookupMapping(rqa.List(FileTreeParser)),
                     doc=(
                         "A mapping between suite id and the files written to"
                         " the AutoTest output folder in that suite."
@@ -225,3 +218,14 @@ class ExtendedAutoTestResult(AutoTestResult):
         )
         res.raw_data = d
         return res
+
+
+import os
+
+if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
+    # fmt: off
+    import datetime
+
+    from .auto_test_result_state import AutoTestResultState
+
+    # fmt: on
