@@ -165,6 +165,19 @@ class FrontendSiteSettings:
     #: Names must be unique, and each tour can contain an arbitrary number of
     #: steps.
     tour_configurations: "t.Sequence[t.Any]"
+    #: Number of decimals for percentage-based grades in assignments, this also
+    #: determines which decimal position the grade is rounded to.
+    assignment_percentage_decimals: "int"
+    #: Number of decimals for point-based grades in assignments, this also
+    #: determines which decimal position the grade is rounded to.
+    assignment_point_decimals: "int"
+    #: Should the lock date be copied from the LMS through LTI, or should we
+    #: allow the user to set it in CodeGrade.
+    lti_lock_date_copying_enabled: "bool"
+    #: Whether the Max Points field within the assignment general settings is
+    #: enabled. If disabled, teachers will not be able to award extra points
+    #: for assignments.
+    assignment_max_points_enabled: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -550,6 +563,41 @@ class FrontendSiteSettings:
                     " tour can contain an arbitrary number of steps."
                 ),
             ),
+            rqa.RequiredArgument(
+                "ASSIGNMENT_PERCENTAGE_DECIMALS",
+                rqa.SimpleValue.int,
+                doc=(
+                    "Number of decimals for percentage-based grades in"
+                    " assignments, this also determines which decimal position"
+                    " the grade is rounded to."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "ASSIGNMENT_POINT_DECIMALS",
+                rqa.SimpleValue.int,
+                doc=(
+                    "Number of decimals for point-based grades in assignments,"
+                    " this also determines which decimal position the grade is"
+                    " rounded to."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "LTI_LOCK_DATE_COPYING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Should the lock date be copied from the LMS through LTI,"
+                    " or should we allow the user to set it in CodeGrade."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "ASSIGNMENT_MAX_POINTS_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the Max Points field within the assignment"
+                    " general settings is enabled. If disabled, teachers will"
+                    " not be able to award extra points for assignments."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -656,6 +704,18 @@ class FrontendSiteSettings:
             "FIND_ELEMENT_INTERVAL": to_dict(self.find_element_interval),
             "FIND_ELEMENT_MAX_TRIES": to_dict(self.find_element_max_tries),
             "TOUR_CONFIGURATIONS": to_dict(self.tour_configurations),
+            "ASSIGNMENT_PERCENTAGE_DECIMALS": to_dict(
+                self.assignment_percentage_decimals
+            ),
+            "ASSIGNMENT_POINT_DECIMALS": to_dict(
+                self.assignment_point_decimals
+            ),
+            "LTI_LOCK_DATE_COPYING_ENABLED": to_dict(
+                self.lti_lock_date_copying_enabled
+            ),
+            "ASSIGNMENT_MAX_POINTS_ENABLED": to_dict(
+                self.assignment_max_points_enabled
+            ),
         }
         return res
 
@@ -717,6 +777,10 @@ class FrontendSiteSettings:
             find_element_interval=parsed.FIND_ELEMENT_INTERVAL,
             find_element_max_tries=parsed.FIND_ELEMENT_MAX_TRIES,
             tour_configurations=parsed.TOUR_CONFIGURATIONS,
+            assignment_percentage_decimals=parsed.ASSIGNMENT_PERCENTAGE_DECIMALS,
+            assignment_point_decimals=parsed.ASSIGNMENT_POINT_DECIMALS,
+            lti_lock_date_copying_enabled=parsed.LTI_LOCK_DATE_COPYING_ENABLED,
+            assignment_max_points_enabled=parsed.ASSIGNMENT_MAX_POINTS_ENABLED,
         )
         res.raw_data = d
         return res
