@@ -71,6 +71,9 @@ class GlobalPermMap:
     #: Users with this permission can get a list of all AutoTest results that
     #: have not yet started running.
     can_view_not_started_autotest_results: "bool"
+    #: Users with this permission have all other permissions in all tenants and
+    #: courses, even when they do not have a role within the tenant or course
+    is_admin: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -247,6 +250,15 @@ class GlobalPermMap:
                     " results that have not yet started running."
                 ),
             ),
+            rqa.RequiredArgument(
+                "is_admin",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission have all other permissions in"
+                    " all tenants and courses, even when they do not have a"
+                    " role within the tenant or course"
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -284,6 +296,7 @@ class GlobalPermMap:
             "can_view_not_started_autotest_results": to_dict(
                 self.can_view_not_started_autotest_results
             ),
+            "is_admin": to_dict(self.is_admin),
         }
         return res
 
@@ -316,6 +329,7 @@ class GlobalPermMap:
             can_edit_coupons=parsed.can_edit_coupons,
             can_see_coupons=parsed.can_see_coupons,
             can_view_not_started_autotest_results=parsed.can_view_not_started_autotest_results,
+            is_admin=parsed.is_admin,
         )
         res.raw_data = d
         return res
