@@ -220,6 +220,42 @@ class PartialAllSiteSettings:
     #: The interval at which we request the server time in case it is out of
     #: sync with the local time.
     server_time_sync_interval: Maybe["datetime.timedelta"] = Nothing
+    #: Whether the is\_admin global permission should be enabled. Users with a
+    #: global role with this permission automatically get all permissions,
+    #: everywhere. Users with a tenant role with this permission automatically
+    #: get all permissions within their tenant.
+    is_admin_permission_enabled: Maybe["bool"] = Nothing
+    #: The interval of time in milliseconds between each search of the starting
+    #: element of a tour once the component trigger is found and visible.
+    tour_polling_interval: Maybe["int"] = Nothing
+    #: The interval of time in milliseconds between each search for the
+    #: anchoring elements of a tour step on the DOM.
+    find_element_interval: Maybe["int"] = Nothing
+    #: The maximum number of tries while searching for the anchoring elements
+    #: of a tour step on the DOM.
+    find_element_max_tries: Maybe["int"] = Nothing
+    #: Tour Configurations for enabled components. For each tour a name, a
+    #: component trigger, and a starting trigger need to be specified. Tour
+    #: Names must be unique, and each tour can contain an arbitrary number of
+    #: steps.
+    tour_configurations: Maybe["t.Sequence[t.Any]"] = Nothing
+    #: Whether CodeGrade should try to automatically copy over assignment
+    #: settings when it is detected that the course of an assignment is copied
+    #: from another course within the same LTI provider.
+    automatic_lti_1p3_assignment_import: Maybe["bool"] = Nothing
+    #: Number of decimals for percentage-based grades in assignments, this also
+    #: determines which decimal position the grade is rounded to.
+    assignment_percentage_decimals: Maybe["int"] = Nothing
+    #: Number of decimals for point-based grades in assignments, this also
+    #: determines which decimal position the grade is rounded to.
+    assignment_point_decimals: Maybe["int"] = Nothing
+    #: Should the lock date be copied from the LMS through LTI, or should we
+    #: allow the user to set it in CodeGrade.
+    lti_lock_date_copying_enabled: Maybe["bool"] = Nothing
+    #: Whether the Max Points field within the assignment general settings is
+    #: enabled. If disabled, teachers will not be able to award extra points
+    #: for assignments.
+    assignment_max_points_enabled: Maybe["bool"] = Nothing
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -739,6 +775,97 @@ class PartialAllSiteSettings:
                     " it is out of sync with the local time."
                 ),
             ),
+            rqa.OptionalArgument(
+                "IS_ADMIN_PERMISSION_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the is\\_admin global permission should be"
+                    " enabled. Users with a global role with this permission"
+                    " automatically get all permissions, everywhere. Users"
+                    " with a tenant role with this permission automatically"
+                    " get all permissions within their tenant."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "TOUR_POLLING_INTERVAL",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The interval of time in milliseconds between each search"
+                    " of the starting element of a tour once the component"
+                    " trigger is found and visible."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "FIND_ELEMENT_INTERVAL",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The interval of time in milliseconds between each search"
+                    " for the anchoring elements of a tour step on the DOM."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "FIND_ELEMENT_MAX_TRIES",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The maximum number of tries while searching for the"
+                    " anchoring elements of a tour step on the DOM."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "TOUR_CONFIGURATIONS",
+                rqa.List(rqa.AnyValue),
+                doc=(
+                    "Tour Configurations for enabled components. For each tour"
+                    " a name, a component trigger, and a starting trigger need"
+                    " to be specified. Tour Names must be unique, and each"
+                    " tour can contain an arbitrary number of steps."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether CodeGrade should try to automatically copy over"
+                    " assignment settings when it is detected that the course"
+                    " of an assignment is copied from another course within"
+                    " the same LTI provider."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "ASSIGNMENT_PERCENTAGE_DECIMALS",
+                rqa.SimpleValue.int,
+                doc=(
+                    "Number of decimals for percentage-based grades in"
+                    " assignments, this also determines which decimal position"
+                    " the grade is rounded to."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "ASSIGNMENT_POINT_DECIMALS",
+                rqa.SimpleValue.int,
+                doc=(
+                    "Number of decimals for point-based grades in assignments,"
+                    " this also determines which decimal position the grade is"
+                    " rounded to."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "LTI_LOCK_DATE_COPYING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Should the lock date be copied from the LMS through LTI,"
+                    " or should we allow the user to set it in CodeGrade."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "ASSIGNMENT_MAX_POINTS_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the Max Points field within the assignment"
+                    " general settings is enabled. If disabled, teachers will"
+                    " not be able to award extra points for assignments."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -916,6 +1043,36 @@ class PartialAllSiteSettings:
         self.server_time_sync_interval = maybe_from_nullable(
             self.server_time_sync_interval
         )
+        self.is_admin_permission_enabled = maybe_from_nullable(
+            self.is_admin_permission_enabled
+        )
+        self.tour_polling_interval = maybe_from_nullable(
+            self.tour_polling_interval
+        )
+        self.find_element_interval = maybe_from_nullable(
+            self.find_element_interval
+        )
+        self.find_element_max_tries = maybe_from_nullable(
+            self.find_element_max_tries
+        )
+        self.tour_configurations = maybe_from_nullable(
+            self.tour_configurations
+        )
+        self.automatic_lti_1p3_assignment_import = maybe_from_nullable(
+            self.automatic_lti_1p3_assignment_import
+        )
+        self.assignment_percentage_decimals = maybe_from_nullable(
+            self.assignment_percentage_decimals
+        )
+        self.assignment_point_decimals = maybe_from_nullable(
+            self.assignment_point_decimals
+        )
+        self.lti_lock_date_copying_enabled = maybe_from_nullable(
+            self.lti_lock_date_copying_enabled
+        )
+        self.assignment_max_points_enabled = maybe_from_nullable(
+            self.assignment_max_points_enabled
+        )
 
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {}
@@ -1157,6 +1314,46 @@ class PartialAllSiteSettings:
             res["SERVER_TIME_SYNC_INTERVAL"] = to_dict(
                 self.server_time_sync_interval.value
             )
+        if self.is_admin_permission_enabled.is_just:
+            res["IS_ADMIN_PERMISSION_ENABLED"] = to_dict(
+                self.is_admin_permission_enabled.value
+            )
+        if self.tour_polling_interval.is_just:
+            res["TOUR_POLLING_INTERVAL"] = to_dict(
+                self.tour_polling_interval.value
+            )
+        if self.find_element_interval.is_just:
+            res["FIND_ELEMENT_INTERVAL"] = to_dict(
+                self.find_element_interval.value
+            )
+        if self.find_element_max_tries.is_just:
+            res["FIND_ELEMENT_MAX_TRIES"] = to_dict(
+                self.find_element_max_tries.value
+            )
+        if self.tour_configurations.is_just:
+            res["TOUR_CONFIGURATIONS"] = to_dict(
+                self.tour_configurations.value
+            )
+        if self.automatic_lti_1p3_assignment_import.is_just:
+            res["AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT"] = to_dict(
+                self.automatic_lti_1p3_assignment_import.value
+            )
+        if self.assignment_percentage_decimals.is_just:
+            res["ASSIGNMENT_PERCENTAGE_DECIMALS"] = to_dict(
+                self.assignment_percentage_decimals.value
+            )
+        if self.assignment_point_decimals.is_just:
+            res["ASSIGNMENT_POINT_DECIMALS"] = to_dict(
+                self.assignment_point_decimals.value
+            )
+        if self.lti_lock_date_copying_enabled.is_just:
+            res["LTI_LOCK_DATE_COPYING_ENABLED"] = to_dict(
+                self.lti_lock_date_copying_enabled.value
+            )
+        if self.assignment_max_points_enabled.is_just:
+            res["ASSIGNMENT_MAX_POINTS_ENABLED"] = to_dict(
+                self.assignment_max_points_enabled.value
+            )
         return res
 
     @classmethod
@@ -1232,6 +1429,16 @@ class PartialAllSiteSettings:
             metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
+            is_admin_permission_enabled=parsed.IS_ADMIN_PERMISSION_ENABLED,
+            tour_polling_interval=parsed.TOUR_POLLING_INTERVAL,
+            find_element_interval=parsed.FIND_ELEMENT_INTERVAL,
+            find_element_max_tries=parsed.FIND_ELEMENT_MAX_TRIES,
+            tour_configurations=parsed.TOUR_CONFIGURATIONS,
+            automatic_lti_1p3_assignment_import=parsed.AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT,
+            assignment_percentage_decimals=parsed.ASSIGNMENT_PERCENTAGE_DECIMALS,
+            assignment_point_decimals=parsed.ASSIGNMENT_POINT_DECIMALS,
+            lti_lock_date_copying_enabled=parsed.LTI_LOCK_DATE_COPYING_ENABLED,
+            assignment_max_points_enabled=parsed.ASSIGNMENT_MAX_POINTS_ENABLED,
         )
         res.raw_data = d
         return res
