@@ -13,6 +13,13 @@ from ..utils import to_dict
 from .assignment_default_grading_scale_setting import (
     AssignmentDefaultGradingScaleSetting,
 )
+from .assignment_max_points_enabled_setting import (
+    AssignmentMaxPointsEnabledSetting,
+)
+from .assignment_percentage_decimals_setting import (
+    AssignmentPercentageDecimalsSetting,
+)
+from .assignment_point_decimals_setting import AssignmentPointDecimalsSetting
 from .at_image_caching_enabled_setting import AtImageCachingEnabledSetting
 from .auto_test_capture_points_message_setting import (
     AutoTestCapturePointsMessageSetting,
@@ -57,6 +64,9 @@ from .auto_test_run_program_message_setting import (
     AutoTestRunProgramMessageSetting,
 )
 from .auto_test_unit_test_message_setting import AutoTestUnitTestMessageSetting
+from .automatic_lti1p3_assignment_import_setting import (
+    AutomaticLti1p3AssignmentImportSetting,
+)
 from .automatic_lti_role_enabled_setting import AutomaticLtiRoleEnabledSetting
 from .blackboard_zip_upload_enabled_setting import (
     BlackboardZipUploadEnabledSetting,
@@ -68,6 +78,8 @@ from .exam_login_max_length_setting import ExamLoginMaxLengthSetting
 from .feedback_threads_initially_collapsed_setting import (
     FeedbackThreadsInitiallyCollapsedSetting,
 )
+from .find_element_interval_setting import FindElementIntervalSetting
+from .find_element_max_tries_setting import FindElementMaxTriesSetting
 from .grading_notifications_enabled_setting import (
     GradingNotificationsEnabledSetting,
 )
@@ -75,10 +87,16 @@ from .groups_enabled_setting import GroupsEnabledSetting
 from .incremental_rubric_submission_enabled_setting import (
     IncrementalRubricSubmissionEnabledSetting,
 )
+from .is_admin_permission_enabled_setting import (
+    IsAdminPermissionEnabledSetting,
+)
 from .jwt_access_token_expires_setting import JwtAccessTokenExpiresSetting
 from .linters_enabled_setting import LintersEnabledSetting
 from .login_token_before_time_setting import LoginTokenBeforeTimeSetting
 from .lti_enabled_setting import LtiEnabledSetting
+from .lti_lock_date_copying_enabled_setting import (
+    LtiLockDateCopyingEnabledSetting,
+)
 from .max_document_update_size_setting import MaxDocumentUpdateSizeSetting
 from .max_dynamo_file_size_setting import MaxDynamoFileSizeSetting
 from .max_dynamo_submission_size_setting import MaxDynamoSubmissionSizeSetting
@@ -124,6 +142,8 @@ from .server_time_sync_interval_setting import ServerTimeSyncIntervalSetting
 from .setting_token_time_setting import SettingTokenTimeSetting
 from .site_email_setting import SiteEmailSetting
 from .student_payment_enabled_setting import StudentPaymentEnabledSetting
+from .tour_configurations_setting import TourConfigurationsSetting
+from .tour_polling_interval_setting import TourPollingIntervalSetting
 
 SiteSettingInput = t.Union[
     AutoTestMaxTimeCommandSetting,
@@ -192,6 +212,16 @@ SiteSettingInput = t.Union[
     MetricGatheringExpressionsSetting,
     ServerTimeDiffToleranceSetting,
     ServerTimeSyncIntervalSetting,
+    IsAdminPermissionEnabledSetting,
+    TourPollingIntervalSetting,
+    FindElementIntervalSetting,
+    FindElementMaxTriesSetting,
+    TourConfigurationsSetting,
+    AutomaticLti1p3AssignmentImportSetting,
+    AssignmentPercentageDecimalsSetting,
+    AssignmentPointDecimalsSetting,
+    LtiLockDateCopyingEnabledSetting,
+    AssignmentMaxPointsEnabledSetting,
 ]
 SiteSettingInputParser = rqa.Lazy(
     lambda: make_union(
@@ -261,5 +291,15 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(MetricGatheringExpressionsSetting),
         ParserFor.make(ServerTimeDiffToleranceSetting),
         ParserFor.make(ServerTimeSyncIntervalSetting),
+        ParserFor.make(IsAdminPermissionEnabledSetting),
+        ParserFor.make(TourPollingIntervalSetting),
+        ParserFor.make(FindElementIntervalSetting),
+        ParserFor.make(FindElementMaxTriesSetting),
+        ParserFor.make(TourConfigurationsSetting),
+        ParserFor.make(AutomaticLti1p3AssignmentImportSetting),
+        ParserFor.make(AssignmentPercentageDecimalsSetting),
+        ParserFor.make(AssignmentPointDecimalsSetting),
+        ParserFor.make(LtiLockDateCopyingEnabledSetting),
+        ParserFor.make(AssignmentMaxPointsEnabledSetting),
     ),
 )
